%define anolis_release 1
%global debug_package %{nil}
%bcond_with doc

Name:           python-sympy
Version:        1.11.1
Release:        %{anolis_release}%{?dist}
Summary:        A Python library for symbolic mathematics

License:        BSD-3-Clause AND MIT
URL:            https://sympy.org/
Source0:        https://github.com/sympy/sympy/archive/sympy-%{version}.tar.gz
Patch0:         sympy-circuitplot.patch

BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  gcc-gfortran
BuildRequires:  python3-devel
BuildRequires:	python3-setuptools

# Documentation
%if %{with doc}
BuildRequires:  graphviz
BuildRequires:  ImageMagick
BuildRequires:  librsvg2-tools
BuildRequires:  make
BuildRequires:  %{py3_dist furo}
BuildRequires:  %{py3_dist linkify-it-py}
BuildRequires:  %{py3_dist numpydoc}
BuildRequires:  %{py3_dist sphinx-copybutton}
BuildRequires:  %{py3_dist sphinx-math-dollar}
BuildRequires:  %{py3_dist sphinx-reredirects}
BuildRequires:  tex(latex)
BuildRequires:  tex-dvipng
%endif
# Tests
%if %{with check}
BuildRequires:  parallel
BuildRequires:  %{py3_dist autowrap}
BuildRequires:  xorg-x11-fonts-Type1
BuildRequires:  xorg-x11-server-Xvfb
%endif

%global _description\
SymPy aims to become a full-featured computer algebra system (CAS)\
while keeping the code as simple as possible in order to be\
comprehensible and easily extensible. SymPy is written entirely in\
Python and does not require any external libraries.

%description %_description

%package -n python3-sympy
Summary:        A Python3 library for symbolic mathematics
Obsoletes:      sympy-texmacs < 1.8

%description -n python3-sympy
SymPy aims to become a full-featured computer algebra system (CAS)
while keeping the code as simple as possible in order to be
comprehensible and easily extensible. SymPy is written entirely in
Python and does not require any external libraries.

%package -n python3-sympy-examples
License:        BSD-3-Clause
Summary:        Sympy examples
Requires:       python3-sympy = %{version}-%{release}

%description -n python3-sympy-examples
This package contains example input for sympy.

%package -n python3-sympy-doc
License:        BSD-3-Clause AND BSD-2-Clause AND MIT AND PSF-2.0
Summary:        Documentation for sympy
Provides:       bundled(js-jquery)
Provides:       bundled(js-underscore)
Requires: 	python3-sympy = %{version}-%{release}

%description -n python3-sympy-doc
HTML documentation for sympy.

%prep
%autosetup -p1 -n sympy-sympy-%{version}
sed -i -e '/^#!\//, 1d' sympy/testing/tests/diagnose_imports.py

%generate_buildrequires
%pyproject_buildrequires

%build
%py3_build

%if %{with doc}
pushd doc
make html SPHINXOPTS=%{?_smp_mflags} PYTHON=%{python3}
make cheatsheet
popd
%endif

%install
%py3_install

## Remove extra files
rm -f %{buildroot}%{_bindir}/{,doc}test

# Don't let an executable script go into the documentation
chmod -R a-x+X examples
sed -i -e '/^#!\//, 1d' %{buildroot}%{python3_sitelib}/sympy/benchmarks/bench_symbench.py

# Fix permissions
chmod 0755 %{buildroot}%{python3_sitelib}/sympy/benchmarks/bench_symbench.py \
      %{buildroot}%{python3_sitelib}/sympy/testing/tests/diagnose_imports.py

# Try to get rid of pyc files, which aren't useful for documentation
find examples/ -name '*.py[co]' -print -delete

%if %{with check}
%check
if [ "$(uname -m)" = "x86_64" ]; then
  # Split into many small chunks to reduce waiting in the end-game
  jobs=%{?_smp_mflags}; jobs=${jobs#-j}; jobs=$((jobs * 3))

  xvfb-run -d \
      parallel %{?_smp_mflags} \
      %{python3} bin/test -v --split {}/$jobs \
      ::: $(bash -c "echo {1..$jobs}")
fi
%endif

%files -n python3-sympy
%{_bindir}/isympy
%{_mandir}/man1/isympy.1*
%{python3_sitelib}/isympy.py
%{python3_sitelib}/sympy
%{python3_sitelib}/sympy-%{version}-*.egg-info
%{python3_sitelib}/__pycache__/*

%files -n python3-sympy-examples
%doc examples/*

%files -n python3-sympy-doc
%doc AUTHORS README.md
%if %{with doc}
%docdir %{_docdir}/sympy-doc/html
%{_docdir}/sympy-doc/html
%doc doc/_build/cheatsheet/cheatsheet.pdf
%doc doc/_build/cheatsheet/combinatoric_cheatsheet.pdf
%endif

%changelog
* Sat Mar 25 2023 happy_orange <songnannan@linux.alibaba.com> - 1.11.1-1
- init package from upstream
